@@ -247,7 +247,7 @@ class AgentLifeCycle:
 
         headers = {"Authorization": "Bearer " + token}
         try:
-            resp = requests.get("https://dev.cognicept.systems/api/v1/aws/assume_role/ecr", headers= headers, timeout = 5)
+            resp = requests.get( args.config.get_cognicept_api_uri() + "aws/assume_role/ecr", headers= headers, timeout = 5)
         except requests.exceptions.Timeout:
             print("Cognicept REST API error: time out.")
             return
@@ -277,17 +277,19 @@ class AgentLifeCycle:
             print("You don't have ECR repository permissions. Check you AWS credentials with Cognicept team.")
 
         images = set(object._docker_images.values())
+        N = len(images)
+        i = 0
         for image_name in images:
-            
+            i = i + 1
             try:
-                i = 0
+                
                 for status in docker_client.pull(image_name, stream = True, decode = True):
                     if("progress" not in status):
                         status["progress"] = ""
-                    print('\r' + image_name + ' - ' + status["status"] + " " + status["progress"], end="")                    
-                print(f"\r{image_name} - {bcolors.OKBLUE}OK{bcolors.ENDC}\033[K")                
+                    print(f"\r[{i}/{N}] {image_name} - " + status["status"] + " " + status["progress"], end="")                    
+                print(f"\r[{i}/{N}] {image_name} - {bcolors.OKBLUE}OK{bcolors.ENDC}\033[K")                
             except docker.errors.ImageNotFound:
-                print(f"\r{image_name} - {bcolors.FAIL}FAILED{bcolors.ENDC}\033[K")
+                print(f"\r[{i}/{N}] {image_name} - {bcolors.FAIL}FAILED{bcolors.ENDC}\033[K")
 
         print("Info: Run `cognicept restart` to redeploy updated agents.")
         
