@@ -101,7 +101,7 @@ class Configuration:
             return False
         
         try:
-            resp = requests.post('https://dev.cognicept.systems/api/v1/user/login', json = {"username": username, "password": password}, timeout = 5)
+            resp = requests.post(object.get_cognicept_api_uri() + 'user/login', json = {"username": username, "password": password}, timeout = 5)
         except requests.exceptions.Timeout:
             print("Cognicept REST API error: time out.")
             return
@@ -136,4 +136,9 @@ class Configuration:
         else:
             # if all fails return empty string
             return ""
-      
\ No newline at end of file
+
+    def get_cognicept_api_uri(object):
+        if "COGNICEPT_API_URI" in object.config:
+            return object.config["COGNICEPT_API_URI"]
+        else:
+            return "https://dev.cognicept.systems/api/v1/"
\ No newline at end of file
